"use strict";
var view_1 = require("ui/core/view");
var common = require("./accordion.common");
var color_1 = require("color");
var platform = require("platform");
var stack_layout_1 = require("ui/layouts/stack-layout");
var dependency_observable_1 = require("ui/core/dependency-observable");
var dependency_observable_2 = require("ui/core/dependency-observable");
var proxy_1 = require("ui/core/proxy");
global.moduleMerge(common, exports);
var Accordion = (function (_super) {
    __extends(Accordion, _super);
    function Accordion() {
        var _this = _super.call(this) || this;
        _this.left = 0;
        _this.top = 0;
        _this.right = 0;
        _this.bottom = 0;
        _this._ios = UIView.new();
        _this._ios.frame = CGRectMake(0, 0, platform.screen.mainScreen.widthPixels, platform.screen.mainScreen.heightPixels);
        return _this;
    }
    Object.defineProperty(Accordion.prototype, "ios", {
        get: function () {
            return this._ios;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Accordion.prototype, "_nativeView", {
        get: function () {
            return this._ios;
        },
        enumerable: true,
        configurable: true
    });
    Accordion.prototype.updateItems = function (oldItems, newItems) {
    };
    Accordion.prototype.addItem = function (view) {
        this._addView(view);
        this.prepareView(view);
        var section = ODSAccordionSectionView.alloc().initWithTitleAndViewSectionStyle(view.headerText, view.ios, this._accordionStyle);
        this._accordion.addSection(section);
    };
    Accordion.prototype.onLoaded = function () {
        var _this = this;
        _super.prototype.onLoaded.call(this);
        this._accordionStyle = ODSAccordionSectionStyle.alloc().init();
        this._accordionStyle.arrowVisible = false;
        if (this.headerHeight) {
            this._accordionStyle.headerHeight = this.headerHeight;
        }
        if (this.headerTextAlignment === "center") {
            this._accordionStyle.headerStyle = ODSAccordionHeaderStyle.LabelCentered;
        }
        else if (this.headerTextAlignment === "right") {
            this._accordionStyle.headerStyle = ODSAccordionHeaderStyle.LabelRight;
        }
        else {
            this._accordionStyle.headerStyle = ODSAccordionHeaderStyle.LabelLeft;
        }
        if (this.headerHeight) {
            this._accordionStyle.headerHeight = this.headerHeight;
        }
        if (this.headerColor) {
            this._accordionStyle.headerBackgroundColor = new color_1.Color(this.headerColor).ios;
        }
        this._accordionStyle.headerBackgroundColor = new color_1.Color(this.headerColor).ios;
        if (this.headerTextColor) {
            this._accordionStyle.headerTitleLabelTextColor = new color_1.Color(this.headerTextColor).ios;
        }
        if (this.headerTextSize) {
            this._accordionStyle.headerTitleLabelFont = UIFont.systemFontOfSize(this.headerTextSize);
        }
        if (this.separatorColor) {
            this._accordionStyle.dividerColor = new color_1.Color(this.separatorColor).ios;
        }
        if (this.items) {
            this._accordionSections = this.items.map(function (item, index) {
                item.tag = index;
                if (item && !item.parent) {
                    _this._addView(item);
                }
                return ODSAccordionSection.alloc().initWithTitleAndView(item.headerText, item.ios);
            });
            this._accordion = ODSAccordionView.alloc().initWithSectionsAndSectionStyle(this._accordionSections, this._accordionStyle);
            this._accordion.frame = CGRectMake(0, 0, this._ios.frame.size.width, this._ios.frame.size.height);
            this._ios.addSubview(this._accordion);
        }
    };
    Accordion.prototype.onMeasure = function (widthMeasureSpec, heightMeasureSpec) {
        this.widthMeasureSpec = widthMeasureSpec;
        this.heightMeasureSpec = heightMeasureSpec;
        _super.prototype.onMeasure.call(this, widthMeasureSpec, heightMeasureSpec);
    };
    Accordion.prototype.onLayout = function (left, top, right, bottom) {
        var _this = this;
        _super.prototype.onLayout.call(this, left, top, right, bottom);
        this.left = left;
        this.top = top;
        this.right = right;
        this.bottom = bottom;
        if (this.items) {
            this.items.forEach(function (item, index) {
                _this.prepareView(item);
            });
        }
    };
    Accordion.prototype.prepareView = function (view) {
        view_1.View.adjustChildLayoutParams(view, this.widthMeasureSpec, this.heightMeasureSpec);
        var result = view_1.View.measureChild(this, view, this.widthMeasureSpec, 660);
        view_1.View.layoutChild(this, view, 0, 0, result.measuredWidth, result.measuredHeight);
        view_1.View.restoreChildOriginalParams(view);
    };
    Object.defineProperty(Accordion.prototype, "_childrenCount", {
        get: function () {
            return this.items ? this.items.length : 0;
        },
        enumerable: true,
        configurable: true
    });
    Accordion.prototype._eachChildView = function (callback) {
        if (!this.items) {
            return;
        }
        for (var i = 0, length = this.items.length; i < length; i++) {
            callback(this.items[i]);
        }
    };
    Accordion.prototype.indexChanged = function (index) {
        this.notifyPropertyChange("selectedIndex", index);
    };
    return Accordion;
}(common.Accordion));
exports.Accordion = Accordion;
var headerTextProperty = new dependency_observable_1.Property("headerText", "Item", new proxy_1.PropertyMetadata(undefined, dependency_observable_2.PropertyMetadataSettings.None));
headerTextProperty.metadata.onSetNativeValue = function (data) {
    var item = data.object;
    item.headerTextChanged(data.newValue, item);
};
var Item = (function (_super) {
    __extends(Item, _super);
    function Item() {
        return _super.call(this) || this;
    }
    Item.prototype.headerTextChanged = function (text, view) {
        var index = view.tag;
        if (view && view.parent.ios) {
            view.parent.ios.subviews[0].subviews[index].subviews[0].setTitleForState(text, UIControlState.Normal);
        }
    };
    Object.defineProperty(Item.prototype, "headerText", {
        get: function () {
            return this._getValue(Item.headerTextProperty);
        },
        set: function (text) {
            this._setValue(Item.headerTextProperty, text);
        },
        enumerable: true,
        configurable: true
    });
    return Item;
}(stack_layout_1.StackLayout));
Item.headerTextProperty = headerTextProperty;
exports.Item = Item;
